ByteSink

Struct ByteSink 

pub struct ByteSink<W: Write, Factory: VerdictFactory<MonitorOutput, OutputTime, Record = Verdict>, MonitorOutput: VerdictRepresentation, OutputTime: OutputTimeRepresentation, Verdict: Into<Vec<u8>>> { /* private fields */ }
Generic VerdictSink that accepts verdicts as bytes and writes them to a Writer.

Implementations

Source

impl<W: Write, Factory: VerdictFactory<MonitorOutput, OutputTime, Record = Verdict>, MonitorOutput: VerdictRepresentation, OutputTime: OutputTimeRepresentation, Verdict: Into<Vec<u8>>> ByteSink<W, Factory, MonitorOutput, OutputTime, Verdict>

pub fn new(writer: W, factory: Factory) -> Self

Create a new ByteSink that receives bytes and forwards them to a writer